@@ -1,12 +1,19 @@
 import datetime
 import socket
 import ssl
+from typing import Tuple
+
 from termcolor import colored
 from servergrimoire.plugin import Plugin
 
 
 def broken_response(url) -> {str, str, str}:
-    return {"status": "KO", "expired": "****-**-** **:**:**", "domain": url}
+    return {
+        "status": "KO",
+        "expired": "****-**-** **:**:**",
+        "domain": url,
+        "organization_name": "***",
+    }
 
 
 class SSLVerify(Plugin):
@@ -17,7 +24,9 @@ class SSLVerify(Plugin):
     def get_directives() -> [str]:
         return ["ssl_check"]
 
-    def __ssl_valid_time_remaining(self, hostname: str) -> datetime.datetime:
+    def __ssl_valid_time_remaining(
+        self, hostname: str
+    ) -> Tuple[datetime.datetime, str]:
         ssl_date_fmt = r"%b %d %H:%M:%S %Y %Z"
 
         context = ssl.create_default_context()
@@ -31,7 +40,16 @@ class SSLVerify(Plugin):
         ssl_info = conn.getpeercert()
         # parse the string from the certificate into a Python datetime object
         self.logger.info(ssl_info)
-        return datetime.datetime.strptime(ssl_info["notAfter"], ssl_date_fmt)
+        try:
+            organizzator = ssl_info["issuer"][2][0][1]
+            self.logger.info(f"How relaise it {organizzator}")
+        except Exception as e:
+            organizzator = "***"
+            self.logger.info(e)
+        return (
+            datetime.datetime.strptime(ssl_info["notAfter"], ssl_date_fmt),
+            organizzator,
+        )
 
     def execute(self, directive: str, data: dict) -> dict:
         """Return test message for hostname cert expiration."""
@@ -39,7 +57,7 @@ class SSLVerify(Plugin):
         output_strng = None
         url = data["url"]
         try:
-            will_expire_in = self.__ssl_valid_time_remaining(url)
+            will_expire_in, organizzator = self.__ssl_valid_time_remaining(url)
         except ResourceWarning:
             output_strng = broken_response(url)
         except OSError:
@@ -67,23 +85,26 @@ class SSLVerify(Plugin):
                     "status": "KO",
                     "expired": str(will_expire_in),
                     "domain": url,
+                    "organization_name": organizzator,
                 }
             elif will_expire_in < limit:
                 output_strng = {
                     "status": "XX",
                     "expired": str(will_expire_in),
                     "domain": url,
+                    "organization_name": organizzator,
                 }
             else:
                 output_strng = {
                     "status": "OK",
                     "expired": str(will_expire_in),
                     "domain": url,
+                    "organization_name": organizzator,
                 }
         self.logger.info(f"{directive} return {output_strng}")
         return output_strng
 
-    def stats(self, directive: str, data: dict) -> ({str: int}, {str: str}):
+    def stats(self, directive: str, data: dict) -> Tuple[dict, dict]:
         try:
             stat = {"OK": 0, "KO": 0, "XX": 0}
             stat[data[directive]["status"]] = 1
@@ -91,13 +112,15 @@ class SSLVerify(Plugin):
             if data[directive]["status"] == "KO":
                 other = {
                     colored(data[directive]["domain"], "red"): colored(
-                        data[directive]["expired"], "red"
+                        f"{data[directive]['expired']} - {data[directive]['organization_name']}",
+                        "red",
                     )
                 }
             elif data[directive]["status"] == "XX":
                 other = {
                     colored(data[directive]["domain"], "yellow"): colored(
-                        data[directive]["expired"], "yellow"
+                        f"{data[directive]['expired']} - {data[directive]['organization_name']}",
+                        "yellow",
                     )
                 }
             return stat, other
